@@ -47,6 +47,13 @@ mod statx;
 pub use at::chmodat;
 #[cfg(any(target_os = "macos", target_os = "ios"))]
 pub use at::fclonefileat;
+#[cfg(not(any(
+    target_os = "wasi",
+    target_os = "redox",
+    target_os = "macos",
+    target_os = "ios"
+)))]
+pub use at::mknodat;
 #[cfg(not(target_os = "redox"))]
 pub use at::{
     accessat, linkat, mkdirat, openat, readlinkat, renameat, statat, symlinkat, unlinkat, utimensat,
@@ -122,7 +129,10 @@ pub use sendfile::sendfile;
 #[cfg(all(target_os = "linux", target_env = "gnu"))]
 pub use statx::statx;
 
-/// Re-export `stat` (or `stat64` where applicable).
+/// `struct stat` for use with [`statat`] and [`fstat`].
+///
+/// [`statat`]: crate::fs::statat
+/// [`fstat`]: crate::fs::fstat
 #[cfg(all(
     libc,
     not(any(
@@ -134,7 +144,10 @@ pub use statx::statx;
 ))]
 pub type Stat = libc::stat;
 
-/// Re-export `stat` (or `stat64` where applicable).
+/// `struct stat` for use with [`statat`] and [`fstat`].
+///
+/// [`statat`]: crate::fs::statat
+/// [`fstat`]: crate::fs::fstat
 #[cfg(all(
     libc,
     any(
@@ -146,15 +159,23 @@ pub type Stat = libc::stat;
 ))]
 pub type Stat = libc::stat64;
 
-/// Re-export `stat` (or `stat64` where applicable).
+/// `struct stat` for use with [`statat`] and [`fstat`].
+///
+/// [`statat`]: crate::fs::statat
+/// [`fstat`]: crate::fs::fstat
 #[cfg(all(linux_raw, target_pointer_width = "32"))]
 pub type Stat = linux_raw_sys::general::stat64;
 
-/// Re-export `stat` (or `stat64` where applicable).
+/// `struct stat` for use with [`statat`] and [`fstat`].
+///
+/// [`statat`]: crate::fs::statat
+/// [`fstat`]: crate::fs::fstat
 #[cfg(all(linux_raw, target_pointer_width = "64"))]
 pub type Stat = linux_raw_sys::general::stat;
 
-/// Re-export `statfs` (or `statfs64` where applicable).
+/// `struct statfs` for use with [`fstatfs`].
+///
+/// [`fstatfs`]: crate::fs::fstatfs
 #[cfg(all(
     libc,
     not(any(
@@ -170,7 +191,9 @@ pub type Stat = linux_raw_sys::general::stat;
 #[allow(clippy::module_name_repetitions)]
 pub type StatFs = libc::statfs;
 
-/// Re-export `stat` (or `stat64` where applicable).
+/// `struct statfs` for use with [`fstatfs`].
+///
+/// [`fstatfs`]: crate::fs::fstatfs
 #[cfg(all(
     libc,
     any(
@@ -182,37 +205,63 @@ pub type StatFs = libc::statfs;
 ))]
 pub type StatFs = libc::statfs64;
 
-/// Re-export `statfs` (or `statfs64` where applicable).
+/// `struct statfs` for use with [`fstatfs`].
+///
+/// [`fstatfs`]: crate::fs::fstatfs
 #[cfg(all(linux_raw, target_pointer_width = "32"))]
 #[allow(clippy::module_name_repetitions)]
 pub type StatFs = linux_raw_sys::general::statfs64;
 
-/// Re-export `statfs` (or `statfs64` where applicable).
+/// `struct statfs` for use with [`fstatfs`].
+///
+/// [`fstatfs`]: crate::fs::fstatfs
 #[cfg(all(linux_raw, target_pointer_width = "64"))]
 #[allow(clippy::module_name_repetitions)]
 pub type StatFs = linux_raw_sys::general::statfs64;
 
-/// Re-export `statx`. Only available on Linux with GLIBC for now.
+/// `struct statx` for use with [`statx`].
+///
+/// Only available on Linux with GLIBC for now.
+///
+/// [`statx`]: crate::fs::statx
 #[cfg(all(libc, all(target_os = "linux", target_env = "gnu")))]
 pub type Statx = libc::statx;
 
-/// Re-export `statx`.
+/// `struct statx` for use with [`statx`].
+///
+/// [`statx`]: crate::fs::statx
 #[cfg(linux_raw)]
 pub type Statx = linux_raw_sys::v5_4::general::statx;
 
-/// Re-export `UTIME_NOW` and `UTIME_OMIT`.
+/// `UTIME_NOW` for use with [`utimensat`].
+///
+/// [`utimensat`]: crate::fs::utimensat
 #[cfg(all(libc, not(target_os = "redox")))]
-pub use libc::{UTIME_NOW, UTIME_OMIT};
+pub use libc::UTIME_NOW;
 
-/// Re-export `UTIME_NOW` and `UTIME_OMIT`.
+/// `UTIME_OMIT` for use with [`utimensat`].
+///
+/// [`utimensat`]: crate::fs::utimensat
+#[cfg(all(libc, not(target_os = "redox")))]
+pub use libc::UTIME_OMIT;
+
+/// `UTIME_NOW` for use with [`utimensat`].
+///
+/// [`utimensat`]: crate::fs::utimensat
 #[cfg(linux_raw)]
-pub use linux_raw_sys::general::{UTIME_NOW, UTIME_OMIT};
+pub use linux_raw_sys::general::UTIME_NOW;
 
-/// Re-export `__fsword_t`.
+/// `UTIME_OMIT` for use with [`utimensat`].
+///
+/// [`utimensat`]: crate::fs::utimensat
+#[cfg(linux_raw)]
+pub use linux_raw_sys::general::UTIME_OMIT;
+
+/// `__fsword_t`.
 #[cfg(all(libc, all(target_os = "linux", not(target_env = "musl"))))]
 pub type FsWord = libc::__fsword_t;
 
-/// Re-export `__fsword_t`.
+/// `__fsword_t`.
 #[cfg(all(
     libc,
     any(target_os = "android", all(target_os = "linux", target_env = "musl")),
@@ -220,7 +269,7 @@ pub type FsWord = libc::__fsword_t;
 ))]
 pub type FsWord = u32;
 
-/// Re-export `__fsword_t`.
+/// `__fsword_t`.
 #[cfg(all(
     libc,
     any(target_os = "android", all(target_os = "linux", target_env = "musl")),
@@ -228,12 +277,15 @@ pub type FsWord = u32;
 ))]
 pub type FsWord = u64;
 
-/// Re-export `__fsword_t`.
+/// `__fsword_t`.
 #[cfg(linux_raw)]
 pub type FsWord = linux_raw_sys::general::__fsword_t;
 
 /// The filesystem magic number for procfs.
-/// <https://man7.org/linux/man-pages/man2/fstatfs.2.html#DESCRIPTION>
+///
+/// See [the `fstatfs` man page] for more information.
+///
+/// [the `fstatfs` man page]: https://man7.org/linux/man-pages/man2/fstatfs.2.html#DESCRIPTION
 #[cfg(all(
     libc,
     any(target_os = "android", target_os = "linux"),
@@ -242,7 +294,10 @@ pub type FsWord = linux_raw_sys::general::__fsword_t;
 pub const PROC_SUPER_MAGIC: FsWord = libc::PROC_SUPER_MAGIC as FsWord;
 
 /// The filesystem magic number for procfs.
-/// <https://man7.org/linux/man-pages/man2/fstatfs.2.html#DESCRIPTION>
+///
+/// See [the `fstatfs` man page] for more information.
+///
+/// [the `fstatfs` man page]: https://man7.org/linux/man-pages/man2/fstatfs.2.html#DESCRIPTION
 #[cfg(all(
     libc,
     any(target_os = "android", target_os = "linux"),
@@ -251,18 +306,51 @@ pub const PROC_SUPER_MAGIC: FsWord = libc::PROC_SUPER_MAGIC as FsWord;
 pub const PROC_SUPER_MAGIC: FsWord = 0x0000_9fa0;
 
 /// The filesystem magic number for procfs.
-/// <https://man7.org/linux/man-pages/man2/fstatfs.2.html#DESCRIPTION>
+///
+/// See [the `fstatfs` man page] for more information.
+///
+/// [the `fstatfs` man page]: https://man7.org/linux/man-pages/man2/fstatfs.2.html#DESCRIPTION
 #[cfg(linux_raw)]
 pub const PROC_SUPER_MAGIC: FsWord = linux_raw_sys::general::PROC_SUPER_MAGIC as FsWord;
 
-/// Re-export `mode_t`.
+/// `mode_t`.
 #[cfg(libc)]
 pub type RawMode = libc::mode_t;
 
-/// Re-export `mode_t`.
-#[cfg(linux_raw)]
+/// `mode_t`.
+#[cfg(all(
+    linux_raw,
+    not(any(
+        target_arch = "x86",
+        target_arch = "sparc",
+        target_arch = "avr",
+        target_arch = "arm"
+    ))
+))]
 pub type RawMode = linux_raw_sys::general::__kernel_mode_t;
 
+/// `mode_t`.
+#[cfg(all(
+    linux_raw,
+    any(
+        target_arch = "x86",
+        target_arch = "sparc",
+        target_arch = "avr",
+        target_arch = "arm"
+    )
+))]
+// Don't use `__kernel_mode_t` since it's `u16` which differs from `st_size`.
+pub type RawMode = std::os::raw::c_uint;
+
+/// `dev_t`.
+#[cfg(libc)]
+pub type Dev = libc::dev_t;
+
+/// `dev_t`.
+#[cfg(linux_raw)]
+// Within the kernel the dev_t is 32-bit, but userspace uses a 64-bit field.
+pub type Dev = u64;
+
 /// Re-export types common to Posix-ish platforms.
 #[cfg(unix)]
 pub use std::os::unix::fs::{DirEntryExt, FileExt, FileTypeExt, MetadataExt, OpenOptionsExt};
