@@ -16,13 +16,15 @@ use {
     unsafe_io::os::posish::{AsRawFd, FromRawFd},
 };
 
-/// `SOCK_*` constants for `socket`.
+/// `SOCK_*` constants for [`socket`].
+///
+/// [`socket`]: crate::net::socket
 #[cfg(libc)]
 #[derive(Debug, Clone, Copy, Eq, PartialEq, Hash)]
 #[repr(transparent)]
 pub struct SocketType(pub(crate) u32);
 
-#[cfg(cfg)]
+#[cfg(libc)]
 impl SocketType {
     /// `SOCK_STREAM`.
     pub const STREAM: Self = Self(libc::SOCK_STREAM as u32);
@@ -40,7 +42,9 @@ impl SocketType {
     pub const RDM: Self = Self(libc::SOCK_RDM as u32);
 }
 
-/// `SOCK_*` constants for `socket`.
+/// `SOCK_*` constants for [`socket`].
+///
+/// [`socket`]: crate::net::socket
 #[cfg(linux_raw)]
 #[derive(Debug, Clone, Copy, Eq, PartialEq, Hash)]
 #[repr(transparent)]
@@ -74,8 +78,7 @@ pub struct AddressFamily(pub(crate) libc::sa_family_t);
 #[cfg(linux_raw)]
 #[derive(Debug, Clone, Copy, Eq, PartialEq, Hash)]
 #[repr(transparent)]
-// Older Linux versions didn't export this typedef.
-pub struct AddressFamily(pub(crate) linux_raw_sys::v5_4::general::__kernel_sa_family_t);
+pub struct AddressFamily(pub(crate) linux_raw_sys::general::__kernel_sa_family_t);
 
 #[cfg(libc)]
 impl AddressFamily {
@@ -106,7 +109,7 @@ impl AddressFamily {
     pub const NETLINK: Self = Self(linux_raw_sys::general::AF_NETLINK as _);
     /// `AF_UNIX`, aka `AF_LOCAL`
     #[doc(alias = "Local")]
-    pub const UNIX: Self = Self(linux_raw_sys::general::AF_LOCAL as _);
+    pub const UNIX: Self = Self(linux_raw_sys::general::AF_UNIX as _);
 }
 
 /// `IPPROTO_*`
@@ -256,6 +259,12 @@ pub enum Protocol {
     Mptcp = linux_raw_sys::v5_11::general::IPPROTO_MPTCP as u32,
 }
 
+impl Default for Protocol {
+    fn default() -> Self {
+        Protocol::Ip
+    }
+}
+
 /// `SHUT_*`
 #[cfg(libc)]
 #[derive(Debug, Clone, Copy, Eq, PartialEq, Hash)]
@@ -284,7 +293,9 @@ pub enum Shutdown {
 
 #[cfg(libc)]
 bitflags! {
-    /// `SOCK_*` constants for `accept`.
+    /// `SOCK_*` constants for [`accept`].
+    ///
+    /// [`accept`]: crate::net::accept
     pub struct AcceptFlags: c_int {
         /// `SOCK_NONBLOCK`
         #[cfg(not(any(target_os = "ios", target_os = "macos")))]
@@ -298,7 +309,9 @@ bitflags! {
 
 #[cfg(linux_raw)]
 bitflags! {
-    /// `SOCK_*` constants for `accept`.
+    /// `SOCK_*` constants for [`accept`].
+    ///
+    /// [`accept`]: crate::net::accept
     pub struct AcceptFlags: c_uint {
         /// `SOCK_NONBLOCK`
         const NONBLOCK = linux_raw_sys::general::O_NONBLOCK;
@@ -326,6 +339,7 @@ fn _socket(domain: AddressFamily, type_: SocketType, protocol: Protocol) -> io::
 }
 
 #[cfg(linux_raw)]
+#[inline]
 fn _socket(domain: AddressFamily, type_: SocketType, protocol: Protocol) -> io::Result<OwnedFd> {
     crate::linux_raw::socket(domain.0.into(), type_.0, protocol as c_uint)
 }
@@ -343,13 +357,14 @@ fn _bind_v4(sockfd: BorrowedFd<'_>, addr: &SocketAddrV4) -> io::Result<()> {
     unsafe {
         zero_ok(libc::bind(
             sockfd.as_raw_fd(),
-            as_ptr(addr).cast::<_>(),
-            size_of::<SocketAddrV4>() as socklen_t,
+            as_ptr(&addr.encode()).cast::<_>(),
+            size_of::<libc::sockaddr_in>() as socklen_t,
         ))
     }
 }
 
 #[cfg(linux_raw)]
+#[inline]
 fn _bind_v4(sockfd: BorrowedFd<'_>, addr: &SocketAddrV4) -> io::Result<()> {
     crate::linux_raw::bind_in(sockfd, addr)
 }
@@ -367,13 +382,14 @@ fn _bind_v6(sockfd: BorrowedFd<'_>, addr: &SocketAddrV6) -> io::Result<()> {
     unsafe {
         zero_ok(libc::bind(
             sockfd.as_raw_fd(),
-            as_ptr(addr).cast::<_>(),
-            size_of::<SocketAddrV6>() as socklen_t,
+            as_ptr(&addr.encode()).cast::<_>(),
+            size_of::<libc::sockaddr_in6>() as socklen_t,
         ))
     }
 }
 
 #[cfg(linux_raw)]
+#[inline]
 fn _bind_v6(sockfd: BorrowedFd<'_>, addr: &SocketAddrV6) -> io::Result<()> {
     crate::linux_raw::bind_in6(sockfd, addr)
 }
@@ -391,13 +407,14 @@ fn _bind_unix(sockfd: BorrowedFd<'_>, addr: &SocketAddrUnix) -> io::Result<()> {
     unsafe {
         zero_ok(libc::bind(
             sockfd.as_raw_fd(),
-            as_ptr(addr).cast::<_>(),
-            size_of::<SocketAddrUnix>() as socklen_t,
+            as_ptr(&addr.encode()).cast::<_>(),
+            size_of::<libc::sockaddr_un>() as socklen_t,
         ))
     }
 }
 
 #[cfg(linux_raw)]
+#[inline]
 fn _bind_unix(sockfd: BorrowedFd<'_>, addr: &SocketAddrUnix) -> io::Result<()> {
     crate::linux_raw::bind_un(sockfd, addr)
 }
@@ -415,13 +432,14 @@ fn _connect_v4(sockfd: BorrowedFd<'_>, addr: &SocketAddrV4) -> io::Result<()> {
     unsafe {
         zero_ok(libc::connect(
             sockfd.as_raw_fd(),
-            as_ptr(addr).cast::<_>(),
-            size_of::<SocketAddrV4>() as socklen_t,
+            as_ptr(&addr.encode()).cast::<_>(),
+            size_of::<libc::sockaddr_in>() as socklen_t,
         ))
     }
 }
 
 #[cfg(linux_raw)]
+#[inline]
 fn _connect_v4(sockfd: BorrowedFd<'_>, addr: &SocketAddrV4) -> io::Result<()> {
     crate::linux_raw::connect_in(sockfd, addr)
 }
@@ -439,13 +457,14 @@ fn _connect_v6(sockfd: BorrowedFd<'_>, addr: &SocketAddrV6) -> io::Result<()> {
     unsafe {
         zero_ok(libc::connect(
             sockfd.as_raw_fd(),
-            as_ptr(addr).cast::<_>(),
-            size_of::<SocketAddrV6>() as socklen_t,
+            as_ptr(&addr.encode()).cast::<_>(),
+            size_of::<libc::sockaddr_in6>() as socklen_t,
         ))
     }
 }
 
 #[cfg(linux_raw)]
+#[inline]
 fn _connect_v6(sockfd: BorrowedFd<'_>, addr: &SocketAddrV6) -> io::Result<()> {
     crate::linux_raw::connect_in6(sockfd, addr)
 }
@@ -463,13 +482,14 @@ fn _connect_unix(sockfd: BorrowedFd<'_>, addr: &SocketAddrUnix) -> io::Result<()
     unsafe {
         zero_ok(libc::connect(
             sockfd.as_raw_fd(),
-            as_ptr(addr).cast::<_>(),
-            size_of::<SocketAddrUnix>() as socklen_t,
+            as_ptr(&addr.encode()).cast::<_>(),
+            size_of::<libc::sockaddr_un>() as socklen_t,
         ))
     }
 }
 
 #[cfg(linux_raw)]
+#[inline]
 fn _connect_unix(sockfd: BorrowedFd<'_>, addr: &SocketAddrUnix) -> io::Result<()> {
     crate::linux_raw::connect_un(sockfd, addr)
 }
@@ -515,7 +535,7 @@ fn _accept(sockfd: BorrowedFd<'_>, flags: AcceptFlags) -> io::Result<(OwnedFd, S
             flags.bits(),
         ))?;
         let owned_fd = OwnedFd::from_raw_fd(raw_fd);
-        Ok((owned_fd, decode_sockaddr(storage.as_ptr())))
+        Ok((owned_fd, decode_sockaddr(storage.as_ptr(), len)))
     }
 }
 
@@ -532,7 +552,7 @@ fn _accept(sockfd: BorrowedFd<'_>, _flags: AcceptFlags) -> io::Result<(OwnedFd,
             &mut len,
         ))?;
         let owned_fd = OwnedFd::from_raw_fd(raw_fd);
-        Ok((owned_fd, decode_sockaddr(storage.as_ptr())))
+        Ok((owned_fd, decode_sockaddr(storage.as_ptr(), len)))
     }
 }
 
@@ -589,6 +609,7 @@ fn _getsockopt_socket_type(fd: BorrowedFd<'_>) -> io::Result<SocketType> {
 }
 
 #[cfg(linux_raw)]
+#[inline]
 fn _getsockopt_socket_type(fd: BorrowedFd<'_>) -> io::Result<SocketType> {
     crate::linux_raw::getsockopt_socket_type(fd).map(SocketType)
 }
@@ -610,7 +631,7 @@ fn _getsockname(sockfd: BorrowedFd<'_>) -> io::Result<SocketAddr> {
             storage.as_mut_ptr().cast::<_>(),
             &mut len,
         ))?;
-        Ok(decode_sockaddr(storage.as_ptr()))
+        Ok(decode_sockaddr(storage.as_ptr(), len))
     }
 }
 
@@ -637,7 +658,7 @@ fn _getpeername(sockfd: BorrowedFd<'_>) -> io::Result<SocketAddr> {
             storage.as_mut_ptr().cast::<_>(),
             &mut len,
         ))?;
-        Ok(decode_sockaddr(storage.as_ptr()))
+        Ok(decode_sockaddr(storage.as_ptr(), len))
     }
 }
 
