@@ -8,8 +8,20 @@ use std::{ffi::OsStr, ops::Deref, path::Path};
 use unsafe_io::os::posish::AsRawFd;
 
 /// Format an integer into a decimal `Path` component, without constructing a
-/// temporary `PathBuf` or `String`. This is used for opening paths such
-/// as `/proc/self/fd/<fd>` on Linux.
+/// temporary `PathBuf` or `String`.
+///
+/// This is used for opening paths such as `/proc/self/fd/<fd>` on Linux.
+///
+/// # Example
+///
+/// ```rust
+/// use posish::path::DecInt;
+///
+/// assert_eq!(
+///     format!("hello {}", DecInt::new(9876).display()),
+///     "hello 9876"
+/// );
+/// ```
 #[derive(Clone)]
 pub struct DecInt {
     buf: [u8; 20],
@@ -33,6 +45,12 @@ impl DecInt {
     pub fn from_fd<'f, Fd: AsFd<'f>>(fd: Fd) -> Self {
         Self::new(fd.as_fd().as_raw_fd())
     }
+
+    /// Return the raw byte buffer.
+    #[inline]
+    pub fn as_bytes(&self) -> &[u8] {
+        &self.buf[..self.len]
+    }
 }
 
 impl Deref for DecInt {
