@@ -1,3 +1,14 @@
+#[cfg(not(any(
+    target_os = "macos",
+    target_os = "ios",
+    target_os = "ios",
+    target_os = "redox",
+    target_os = "freebsd",
+    target_os = "openbsd",
+    target_os = "emscripten",
+    target_os = "wasi",
+)))]
+use crate::io;
 use crate::time::Timespec;
 #[cfg(all(
     libc,
@@ -12,7 +23,7 @@ use crate::time::Timespec;
         target_os = "wasi",
     ))
 ))]
-use std::ptr;
+use std::ptr::null_mut;
 #[cfg(libc)]
 use {crate::zero_ok, std::mem::MaybeUninit};
 
@@ -140,17 +151,12 @@ pub fn clock_nanosleep_relative(id: ClockId, request: &Timespec) -> NanosleepRel
     let mut remain = MaybeUninit::<Timespec>::uninit();
     let flags = 0;
     unsafe {
-        match zero_ok(libc::clock_nanosleep(
-            id as libc::clockid_t,
-            flags,
-            request,
-            remain.as_mut_ptr(),
-        )) {
-            Ok(()) => NanosleepRelativeResult::Ok,
-            Err(crate::io::Error::INTR) => {
+        match libc::clock_nanosleep(id as libc::clockid_t, flags, request, remain.as_mut_ptr()) {
+            0 => NanosleepRelativeResult::Ok,
+            err if err == crate::io::Error::INTR.0 => {
                 NanosleepRelativeResult::Interrupted(remain.assume_init())
             }
-            Err(err) => NanosleepRelativeResult::Err(err),
+            err => NanosleepRelativeResult::Err(io::Error(err)),
         }
     }
 }
@@ -178,19 +184,19 @@ pub fn clock_nanosleep_relative(id: ClockId, request: &Timespec) -> NanosleepRel
     target_os = "wasi",
 ))))]
 #[inline]
-pub fn clock_nanosleep_absolute(id: ClockId, request: &Timespec) -> Result<(), ()> {
+pub fn clock_nanosleep_absolute(id: ClockId, request: &Timespec) -> io::Result<()> {
     let flags = libc::TIMER_ABSTIME;
-    zero_ok(unsafe {
-        libc::clock_nanosleep(id as libc::clockid_t, flags, request, ptr::null_mut())
-    })
-    .map_err(|_| ())
+    match unsafe { libc::clock_nanosleep(id as libc::clockid_t, flags, request, null_mut()) } {
+        0 => Ok(()),
+        err => Err(io::Error(err)),
+    }
 }
 
 /// `clock_nanosleep(id, TIMER_ABSTIME, request, NULL)`
 #[cfg(linux_raw)]
 #[inline]
-pub fn clock_nanosleep_absolute(id: ClockId, request: &Timespec) -> Result<(), ()> {
-    crate::linux_raw::clock_nanosleep_absolute(id as i32, request).map_err(|_err| ())
+pub fn clock_nanosleep_absolute(id: ClockId, request: &Timespec) -> io::Result<()> {
+    crate::linux_raw::clock_nanosleep_absolute(id as i32, request)
 }
 
 /// `nanosleep(request, remain)`
@@ -221,6 +227,7 @@ pub fn nanosleep(request: &Timespec) -> NanosleepRelativeResult {
 }
 
 /// A return type for `nanosleep` and `clock_nanosleep_relative`.
+#[derive(Debug, Clone)]
 pub enum NanosleepRelativeResult {
     /// The sleep completed normally.
     Ok,
