@@ -56,4 +56,18 @@ fn test_file() {
     let stat = posish::fs::fstat(file.as_fd()).unwrap();
     assert!(stat.st_size > 0);
     assert!(stat.st_blocks > 0);
+
+    #[cfg(not(any(target_os = "netbsd", target_os = "wasi")))]
+    // not implemented in libc for netbsd yet
+    {
+        let statfs = posish::fs::fstatfs(file.as_fd()).unwrap();
+        assert!(statfs.f_blocks > 0);
+    }
+
+    assert_eq!(
+        posish::io::is_read_write(file.as_fd()).unwrap(),
+        (true, false)
+    );
+
+    assert_ne!(posish::io::ioctl_fionread(file.as_fd()).unwrap(), 0);
 }
